==> ejc-equipment-api-3.0.0-20200610.073213-36-sources.jar: com/ejianc/business/equipment/vo/PurchaseChangeRecordVO.java <==
package com.ejianc.business.equipment.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 设备合同变更记录
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public class PurchaseChangeRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;

    /**
     * 初始版本金额
     */
    private BigDecimal baseTaxMoney;

    /**
     * 累计变更金额
     */
//    private BigDecimal sumChangeMny;

    /**
     * 累计变更率
     */
//    private BigDecimal sumScale;

    // 设备明细子表
    private List<PurchaseChangeVO> changeRecord = new ArrayList<PurchaseChangeVO>();

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getBaseTaxMoney() {
        return baseTaxMoney;
    }

    public void setBaseTaxMoney(BigDecimal baseTaxMoney) {
        this.baseTaxMoney = baseTaxMoney;
    }

//    public BigDecimal getSumChangeMny() {
//        return sumChangeMny;
//    }
//
//    public void setSumChangeMny(BigDecimal sumChangeMny) {
//        this.sumChangeMny = sumChangeMny;
//    }
//
//    public BigDecimal getSumScale() {
//        return sumScale;
//    }
//
//    public void setSumScale(BigDecimal sumScale) {
//        this.sumScale = sumScale;
//    }

    public List<PurchaseChangeVO> getChangeRecord() {
        return changeRecord;
    }

    public void setChangeRecord(List<PurchaseChangeVO> changeRecord) {
        this.changeRecord = changeRecord;
    }
}

==> ejc-equipment-api-3.0.0-20210709.083055-265-sources.jar: com/ejianc/business/equipment/vo/PurchaseChangeRecordVO.java <==
package com.ejianc.business.equipment.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 设备合同变更记录
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public class PurchaseChangeRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;

    /**
     * 初始版本金额
     */
    private BigDecimal baseTaxMoney;

    /**
     * 累计变更金额
     */
    private BigDecimal sumChangeMny;

    /**
     * 累计变更率
     */
    private BigDecimal sumScale;

    // 设备明细子表
    private List<PurchaseChangeVO> changeRecord = new ArrayList<PurchaseChangeVO>();

    private Integer settlementType;

    public Integer getSettlementType() {
        return settlementType;
    }

    public void setSettlementType(Integer settlementType) {
        this.settlementType = settlementType;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getBaseTaxMoney() {
        return baseTaxMoney;
    }

    public void setBaseTaxMoney(BigDecimal baseTaxMoney) {
        this.baseTaxMoney = baseTaxMoney;
    }

    public BigDecimal getSumChangeMny() {
        return sumChangeMny;
    }

    public void setSumChangeMny(BigDecimal sumChangeMny) {
        this.sumChangeMny = sumChangeMny;
    }

    public BigDecimal getSumScale() {
        return sumScale;
    }

    public void setSumScale(BigDecimal sumScale) {
        this.sumScale = sumScale;
    }

    public List<PurchaseChangeVO> getChangeRecord() {
        return changeRecord;
    }

    public void setChangeRecord(List<PurchaseChangeVO> changeRecord) {
        this.changeRecord = changeRecord;
    }
}
